==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Account_Profile.pm <==
package WebGUI::i18n::Dutch::Account_Profile;
use utf8;
our $I18N = {
  'back label' => {
    'lastUpdated' => 1227609820,
    'message' => 'Terug naar de site'
  },
  'back to profile label' => {
    'lastUpdated' => 1227609833,
    'message' => 'Terug naar het profiel'
  },
  'edit my profile' => {
    'lastUpdated' => 1228763721,
    'message' => 'Bewerk mijn profiel'
  },
  'error label' => {
    'lastUpdated' => 1228763731,
    'message' => 'Fout'
  },
  'friends only' => {
    'lastUpdated' => 1228763751,
    'message' => 'Uw profiel is zichtbaar voor vrienden.'
  },
  'friends only label' => {
    'lastUpdated' => 1228763765,
    'message' => 'Alleen vrienden'
  },
  'member since' => {
    'lastUpdated' => 1228763775,
    'message' => 'Lid sinds'
  },
  'private label' => {
    'lastUpdated' => 1228763797,
    'message' => 'Priv&eacute;'
  },
  'private profile' => {
    'lastUpdated' => 1228763817,
    'message' => 'Uw profiel is priv&eacute;.'
  },
  'profile as others label' => {
    'lastUpdated' => 1228763843,
    'message' => 'Bekijk mijn profiel zoals anderen dat zien.'
  },
  'profile edit layout template hoverHelp' => {
    'lastUpdated' => 1228764905,
    'message' => 'Kies een layout uit de lijst voor het tonen van de verschillende account functies die zichtbaar zijn voor anderen en de inhoud van de plugin die momenteel geselecteerd is.'
  },
  'profile edit layout template label' => {
    'lastUpdated' => 1228764969,
    'message' => 'Tonen layout sjabloon'
  },
  'profile edit template hoverHelp' => {
    'lastUpdated' => 1228764792,
    'message' => 'Kies het sjabloon voor het bewerken van een profiel.'
  },
  'profile edit template label' => {
    'lastUpdated' => 1228764771,
    'message' => 'Bewerk sjabloon'
  },
  'profile error template hoverHelp' => {
    'lastUpdated' => 1228764756,
    'message' => 'Kies het sjabloon voor het tonen van fouten in het profiel aan de gebruiker.'
  },
  'profile error template label' => {
    'lastUpdated' => 1228764714,
    'message' => 'Fout in het sjabloon'
  },
  'profile layout template hoverHelp' => {
    'lastUpdated' => 1229181999,
    'message' => 'Kies een layout uit de lijst voor het tonen van de verschillende account functies die bewerkbaar zijn voor de gebruiker en de inhoud van de plugin die momenteel geselecteerd is.'
  },
  'profile layout template label' => {
    'lastUpdated' => 1228764216,
    'message' => 'Bewerk layout sjabloon'
  },
  'profile not public error' => {
    'lastUpdated' => 1228764131,
    'message' => 'Het profiel van deze gebruiker is niet publiek toegankelijk.'
  },
  'profile style template hoverHelp' => {
    'lastUpdated' => 1228764194,
    'message' => 'Kies een stijl sjabloon uit de lijst voor het tonen van de inkomende mail.'
  },
  'profile style template label' => {
    'lastUpdated' => 1228764104,
    'message' => 'Stijl sjabloon'
  },
  'profile view template hoverHelp' => {
    'lastUpdated' => 1228764093,
    'message' => 'Kies het sjabloon voor het tonen van een profiel.'
  },
  'profile view template label' => {
    'lastUpdated' => 1228764065,
    'message' => 'Bekijk sjabloon'
  },
  'public label' => {
    'lastUpdated' => 1228763859,
    'message' => 'Publiek'
  },
  'public profile' => {
    'lastUpdated' => 1228763878,
    'message' => 'Uw profiel is publiek toegankelijk.'
  },
  'required field' => {
    'lastUpdated' => 1228763892,
    'message' => 'Vereist'
  },
  'save changes' => {
    'lastUpdated' => 1228763903,
    'message' => 'Veranderingen opslaan'
  },
  'send friend request label' => {
    'lastUpdated' => 1228764054,
    'message' => 'Vrienden uitnodigen'
  },
  'send private message label' => {
    'lastUpdated' => 1228764013,
    'message' => 'Priv&eacute; bericht verzenden'
  },
  'set by admin' => {
    'lastUpdated' => 1228763936,
    'message' => 'De administrator heeft dit veld als niet zichtbaar ingesteld.'
  },
  'title' => {
    'lastUpdated' => 1229182005,
    'message' => 'Profiel'
  },
  'view my profile' => {
    'lastUpdated' => 1228763955,
    'message' => 'Bekijk mijn profiel'
  },
  'visitor profile restricted' => {
    'lastUpdated' => 1228763992,
    'message' => 'Het bezoekersprofiel is beperkt.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Account_Profile.pm <==
package WebGUI::i18n::Dutch::Account_Profile;
use utf8;
our $I18N = {
  'ascending' => {
    'lastUpdated' => '1308722175',
    'message' => 'opklimmend alfabetisch sorteren'
  },
  'assetManagerSortColumn label' => {
    'lastUpdated' => '1308722328',
    'message' => 'Asset Manager sorteringskolom'
  },
  'assetManagerSortDirection label' => {
    'lastUpdated' => '1308722378',
    'message' => 'Asset Manager sorteringsrichting'
  },
  'back label' => {
    'lastUpdated' => '1227609820',
    'message' => 'Terug naar de site'
  },
  'back to profile label' => {
    'lastUpdated' => '1227609833',
    'message' => 'Terug naar het profiel'
  },
  'descending' => {
    'lastUpdated' => '1308722193',
    'message' => 'afstijgend alfabetisch sorteren'
  },
  'edit my profile' => {
    'lastUpdated' => '1228763721',
    'message' => 'Bewerk mijn profiel'
  },
  'error label' => {
    'lastUpdated' => '1228763731',
    'message' => 'Fout'
  },
  'friends only' => {
    'lastUpdated' => '1228763751',
    'message' => 'Uw profiel is zichtbaar voor vrienden.'
  },
  'friends only label' => {
    'lastUpdated' => '1228763765',
    'message' => 'Alleen vrienden'
  },
  'member since' => {
    'lastUpdated' => '1228763775',
    'message' => 'Lid sinds'
  },
  'private label' => {
    'lastUpdated' => '1228763797',
    'message' => 'Priv&eacute;'
  },
  'private profile' => {
    'lastUpdated' => '1228763817',
    'message' => 'Uw profiel is priv&eacute;.'
  },
  'profile as others label' => {
    'lastUpdated' => '1228763843',
    'message' => 'Bekijk mijn profiel zoals anderen dat zien.'
  },
  'profile edit layout template hoverHelp' => {
    'lastUpdated' => '1228764905',
    'message' => 'Kies een layout uit de lijst voor het tonen van de verschillende account functies die zichtbaar zijn voor anderen en de inhoud van de plugin die momenteel geselecteerd is.'
  },
  'profile edit layout template label' => {
    'lastUpdated' => '1228764969',
    'message' => 'Tonen layout sjabloon'
  },
  'profile edit template hoverHelp' => {
    'lastUpdated' => '1228764792',
    'message' => 'Kies het sjabloon voor het bewerken van een profiel.'
  },
  'profile edit template label' => {
    'lastUpdated' => '1228764771',
    'message' => 'Bewerk sjabloon'
  },
  'profile error template hoverHelp' => {
    'lastUpdated' => '1228764756',
    'message' => 'Kies het sjabloon voor het tonen van fouten in het profiel aan de gebruiker.'
  },
  'profile error template label' => {
    'lastUpdated' => '1228764714',
    'message' => 'Fout in het sjabloon'
  },
  'profile layout template hoverHelp' => {
    'lastUpdated' => '1229181999',
    'message' => 'Kies een layout uit de lijst voor het tonen van de verschillende account functies die bewerkbaar zijn voor de gebruiker en de inhoud van de plugin die momenteel geselecteerd is.'
  },
  'profile layout template label' => {
    'lastUpdated' => '1228764216',
    'message' => 'Bewerk layout sjabloon'
  },
  'profile not public error' => {
    'lastUpdated' => '1228764131',
    'message' => 'Het profiel van deze gebruiker is niet publiek toegankelijk.'
  },
  'profile style template hoverHelp' => {
    'lastUpdated' => '1228764194',
    'message' => 'Kies een stijl sjabloon uit de lijst voor het tonen van de inkomende mail.'
  },
  'profile style template label' => {
    'lastUpdated' => '1315853665',
    'message' => 'Stijl sjabloon'
  },
  'profile view template hoverHelp' => {
    'lastUpdated' => '1228764093',
    'message' => 'Kies het sjabloon voor het tonen van een profiel.'
  },
  'profile view template label' => {
    'lastUpdated' => '1228764065',
    'message' => 'Bekijk sjabloon'
  },
  'public label' => {
    'lastUpdated' => '1228763859',
    'message' => 'Publiek'
  },
  'public profile' => {
    'lastUpdated' => '1228763878',
    'message' => 'Uw profiel is publiek toegankelijk.'
  },
  'required field' => {
    'lastUpdated' => '1228763892',
    'message' => 'Vereist'
  },
  'save changes' => {
    'lastUpdated' => '1228763903',
    'message' => 'Veranderingen opslaan'
  },
  'send friend request label' => {
    'lastUpdated' => '1228764054',
    'message' => 'Vrienden uitnodigen'
  },
  'send private message label' => {
    'lastUpdated' => '1228764013',
    'message' => 'Priv&eacute; bericht verzenden'
  },
  'set by admin' => {
    'lastUpdated' => '1228763936',
    'message' => 'De administrator heeft dit veld als niet zichtbaar ingesteld.'
  },
  'title' => {
    'lastUpdated' => '1229182005',
    'message' => 'Profiel'
  },
  'view my profile' => {
    'lastUpdated' => '1228763955',
    'message' => 'Bekijk mijn profiel'
  },
  'visitor profile restricted' => {
    'lastUpdated' => '1228763992',
    'message' => 'Het bezoekersprofiel is beperkt.'
  }
}
;

1;
